@@ -176,8 +176,9 @@ armnn.Node = class {
                     const schema = metadata.attribute(name, key);
                     const type = schema ? schema.type : null;
                     let value = ArrayBuffer.isView(obj) ? Array.from(obj) : obj;
-                    if (armnn.schema[type]) {
-                        value = armnn.Utility.enum(type, value);
+                    const enumType = armnn.schema[type];
+                    if (enumType) {
+                        value = enumType[value] || value;
                     }
                     const attribute = new armnn.Argument(key, value, type);
                     this.attributes.push(attribute);
@@ -282,25 +283,6 @@ armnn.TensorShape = class {
     }
 };
 
-armnn.Utility = class {
-
-    static enum(name, value) {
-        const type = name && armnn.schema ? armnn.schema[name] : undefined;
-        if (type) {
-            armnn.Utility._enums = armnn.Utility._enums || new Map();
-            if (!armnn.Utility._enums.has(name)) {
-                const entries = new Map(Object.entries(type).map(([key, value]) => [value, key]));
-                armnn.Utility._enums.set(name, entries);
-            }
-            const entries = armnn.Utility._enums.get(name);
-            if (entries.has(value)) {
-                return entries.get(value);
-            }
-        }
-        return value;
-    }
-};
-
 armnn.Error = class extends Error {
 
     constructor(message) {
