@@ -103,18 +103,28 @@ if (!DataView.prototype.getFloat4e2m1) {
 if (!DataView.prototype.getFloat8e4m3) {
     DataView.__float8e4m3_float32 = new Float32Array(1);
     DataView.__float8e4m3_uint32 = new Uint32Array(DataView.__float8e4m3_float32.buffer, DataView.__float8e4m3_float32.byteOffset, 1);
-    DataView.prototype.getFloat8e4m3 = function(byteOffset, fn, uz) {
+    DataView.prototype.getFloat8e4m3 = function(byteOffset, fn, uz, bias) {
         const value = this.getUint8(byteOffset);
-        let exponent_bias = 7;
+        const exponent_bias = bias || (uz ? 8 : 7);
         if (uz) {
-            exponent_bias = 8;
             if (value === 0x80) {
                 return NaN;
             }
-        } else if (value === 255) {
-            return -NaN;
-        } else if (value === 0x7f) {
-            return NaN;
+        } else if (fn) {
+            if (value === 255) {
+                return -NaN;
+            } else if (value === 0x7f) {
+                return NaN;
+            }
+        } else {
+            const expo = (value & 0x78) >> 3;
+            const mant = value & 0x07;
+            if (expo === 15) {
+                if (mant === 0) {
+                    return (value & 0x80) ? -Infinity : Infinity;
+                }
+                return NaN;
+            }
         }
         let expo = (value & 0x78) >> 3;
         let mant = value & 0x07;
@@ -243,6 +253,19 @@ if (!DataView.prototype.getFloat8e3m4) {
     };
 }
 
+if (!DataView.prototype.getFloat8e8m0fnu) {
+    DataView.__float8e8m0fnu_float32 = new Float32Array(1);
+    DataView.__float8e8m0fnu_uint32 = new Uint32Array(DataView.__float8e8m0fnu_float32.buffer, DataView.__float8e8m0fnu_float32.byteOffset, 1);
+    DataView.prototype.getFloat8e8m0fnu = function(byteOffset) {
+        const value = this.getUint8(byteOffset);
+        if (value === 255) {
+            return NaN;
+        }
+        DataView.__float8e8m0fnu_uint32[0] = value << 23;
+        return DataView.__float8e8m0fnu_float32[0];
+    };
+}
+
 DataView.prototype.getInt48 = DataView.prototype.getInt48 || function(offset, littleEndian) {
     let value = 0;
     if (littleEndian) {
@@ -1023,6 +1046,11 @@ base.Tensor = class {
                         results.push(view.getFloat8e3m4(offset));
                     }
                     break;
+                case 'float8e4m3':
+                    for (; offset < max; offset += stride) {
+                        results.push(view.getFloat8e4m3(offset, false, false));
+                    }
+                    break;
                 case 'float8e4m3fn':
                     for (; offset < max; offset += stride) {
                         results.push(view.getFloat8e4m3(offset, true, false));
@@ -1033,6 +1061,11 @@ base.Tensor = class {
                         results.push(view.getFloat8e4m3(offset, true, true));
                     }
                     break;
+                case 'float8e4m3b11fnuz':
+                    for (; offset < max; offset += stride) {
+                        results.push(view.getFloat8e4m3(offset, true, true, 11));
+                    }
+                    break;
                 case 'float8e5m2':
                     for (; offset < max; offset += stride) {
                         results.push(view.getFloat8e5m2(offset, false, false));
@@ -1043,6 +1076,11 @@ base.Tensor = class {
                         results.push(view.getFloat8e5m2(offset, true, true));
                     }
                     break;
+                case 'float8e8m0fnu':
+                    for (; offset < max; offset += stride) {
+                        results.push(view.getFloat8e8m0fnu(offset));
+                    }
+                    break;
                 default:
                     throw new Error(`Unsupported tensor data type '${dataType}'.`);
             }
@@ -1352,7 +1390,7 @@ base.Metadata = class {
             'pkl', 'pickle', 'joblib', 'safetensors',
             'ptl', 't7',
             'dlc', 'uff', 'armnn', 'kann', 'kgraph', 'tosa',
-            'mnn', 'ms', 'ncnn', 'om', 'tm', 'mge', 'tmfile', 'tnnproto', 'xmodel', 'kmodel', 'rknn',
+            'mnn', 'ms', 'ncnn', 'om', 'tm', 'mge', 'tmfile', 'tnnproto', 'xmodel', 'kmodel', 'rknn', 'espdl',
             'tar', 'zip'
         ];
     }
