@@ -877,6 +877,19 @@ vulkan.TensorType = class {
         }
         this.dataType = types[tensor.datatype];
         this.shape = new vulkan.TensorShape(Array.from(tensor.dims));
+        const vkgraph = executorch.schema.vkgraph;
+        if (tensor.memory_layout !== vkgraph.VkMemoryLayout.DEFAULT_LAYOUT) {
+            this.denotation = vkgraph.VkMemoryLayout[tensor.memory_layout];
+            if (!this.denotation) {
+                throw new vulkan.Error(`Unsupported memory layout '${tensor.memory_layout}'.`);
+            }
+        }
+        if (tensor.storage_type !== vkgraph.VkStorageType.DEFAULT_STORAGE) {
+            this.layout = vkgraph.VkStorageType[tensor.storage_type];
+            if (!this.layout) {
+                throw new vulkan.Error(`Unsupported storage type '${tensor.storage_type}'.`);
+            }
+        }
     }
 
     toString() {
