@@ -4,101 +4,101 @@ export const tosa = {};
 tosa.v0 = {};
 
 tosa.v0.DType = {
-    UNKNOWN: 0,
-    BOOL: 1,
-    UINT8: 2,
-    INT4: 3,
-    INT8: 4,
-    INT16: 5,
-    INT32: 6,
-    INT48: 7,
-    FP32: 8,
-    UINT16: 9,
-    FP16: 10,
-    BF16: 11,
-    SHAPE: 12
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    BOOL: 1, '1': 'BOOL',
+    UINT8: 2, '2': 'UINT8',
+    INT4: 3, '3': 'INT4',
+    INT8: 4, '4': 'INT8',
+    INT16: 5, '5': 'INT16',
+    INT32: 6, '6': 'INT32',
+    INT48: 7, '7': 'INT48',
+    FP32: 8, '8': 'FP32',
+    UINT16: 9, '9': 'UINT16',
+    FP16: 10, '10': 'FP16',
+    BF16: 11, '11': 'BF16',
+    SHAPE: 12, '12': 'SHAPE'
 };
 
 tosa.v0.ResizeMode = {
-    UNKNOWN: 0,
-    NEAREST: 1,
-    BILINEAR: 2
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    NEAREST: 1, '1': 'NEAREST',
+    BILINEAR: 2, '2': 'BILINEAR'
 };
 
 tosa.v0.Op = {
-    UNKNOWN: 0,
-    ARGMAX: 1,
-    AVG_POOL2D: 2,
-    CONV2D: 3,
-    CONV3D: 4,
-    DEPTHWISE_CONV2D: 5,
-    FULLY_CONNECTED: 6,
-    MATMUL: 7,
-    MAX_POOL2D: 8,
-    TRANSPOSE_CONV2D: 9,
-    CLAMP: 10,
-    RESERVED: 11,
-    SIGMOID: 12,
-    TANH: 13,
-    ADD: 14,
-    ARITHMETIC_RIGHT_SHIFT: 15,
-    BITWISE_AND: 16,
-    BITWISE_OR: 17,
-    BITWISE_XOR: 18,
-    INTDIV: 19,
-    LOGICAL_AND: 20,
-    LOGICAL_LEFT_SHIFT: 21,
-    LOGICAL_RIGHT_SHIFT: 22,
-    LOGICAL_OR: 23,
-    LOGICAL_XOR: 24,
-    MAXIMUM: 25,
-    MINIMUM: 26,
-    MUL: 27,
-    POW: 28,
-    SUB: 29,
-    TABLE: 30,
-    ABS: 31,
-    BITWISE_NOT: 32,
-    CEIL: 33,
-    CLZ: 34,
-    EXP: 35,
-    FLOOR: 36,
-    LOG: 37,
-    LOGICAL_NOT: 38,
-    NEGATE: 39,
-    RECIPROCAL: 40,
-    RSQRT: 41,
-    SELECT: 42,
-    EQUAL: 43,
-    GREATER: 44,
-    GREATER_EQUAL: 45,
-    REDUCE_ANY: 46,
-    REDUCE_ALL: 47,
-    REDUCE_MAX: 48,
-    REDUCE_MIN: 49,
-    REDUCE_PRODUCT: 50,
-    REDUCE_SUM: 51,
-    CONCAT: 52,
-    PAD: 53,
-    RESHAPE: 54,
-    REVERSE: 55,
-    SLICE: 56,
-    TILE: 57,
-    TRANSPOSE: 58,
-    GATHER: 59,
-    SCATTER: 60,
-    RESIZE: 61,
-    CAST: 62,
-    RESCALE: 63,
-    CONST: 64,
-    IDENTITY: 65,
-    CUSTOM: 66,
-    COND_IF: 67,
-    WHILE_LOOP: 68,
-    FFT2D: 69,
-    RFFT2D: 70,
-    ERF: 71,
-    DIM: 72
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    ARGMAX: 1, '1': 'ARGMAX',
+    AVG_POOL2D: 2, '2': 'AVG_POOL2D',
+    CONV2D: 3, '3': 'CONV2D',
+    CONV3D: 4, '4': 'CONV3D',
+    DEPTHWISE_CONV2D: 5, '5': 'DEPTHWISE_CONV2D',
+    FULLY_CONNECTED: 6, '6': 'FULLY_CONNECTED',
+    MATMUL: 7, '7': 'MATMUL',
+    MAX_POOL2D: 8, '8': 'MAX_POOL2D',
+    TRANSPOSE_CONV2D: 9, '9': 'TRANSPOSE_CONV2D',
+    CLAMP: 10, '10': 'CLAMP',
+    RESERVED: 11, '11': 'RESERVED',
+    SIGMOID: 12, '12': 'SIGMOID',
+    TANH: 13, '13': 'TANH',
+    ADD: 14, '14': 'ADD',
+    ARITHMETIC_RIGHT_SHIFT: 15, '15': 'ARITHMETIC_RIGHT_SHIFT',
+    BITWISE_AND: 16, '16': 'BITWISE_AND',
+    BITWISE_OR: 17, '17': 'BITWISE_OR',
+    BITWISE_XOR: 18, '18': 'BITWISE_XOR',
+    INTDIV: 19, '19': 'INTDIV',
+    LOGICAL_AND: 20, '20': 'LOGICAL_AND',
+    LOGICAL_LEFT_SHIFT: 21, '21': 'LOGICAL_LEFT_SHIFT',
+    LOGICAL_RIGHT_SHIFT: 22, '22': 'LOGICAL_RIGHT_SHIFT',
+    LOGICAL_OR: 23, '23': 'LOGICAL_OR',
+    LOGICAL_XOR: 24, '24': 'LOGICAL_XOR',
+    MAXIMUM: 25, '25': 'MAXIMUM',
+    MINIMUM: 26, '26': 'MINIMUM',
+    MUL: 27, '27': 'MUL',
+    POW: 28, '28': 'POW',
+    SUB: 29, '29': 'SUB',
+    TABLE: 30, '30': 'TABLE',
+    ABS: 31, '31': 'ABS',
+    BITWISE_NOT: 32, '32': 'BITWISE_NOT',
+    CEIL: 33, '33': 'CEIL',
+    CLZ: 34, '34': 'CLZ',
+    EXP: 35, '35': 'EXP',
+    FLOOR: 36, '36': 'FLOOR',
+    LOG: 37, '37': 'LOG',
+    LOGICAL_NOT: 38, '38': 'LOGICAL_NOT',
+    NEGATE: 39, '39': 'NEGATE',
+    RECIPROCAL: 40, '40': 'RECIPROCAL',
+    RSQRT: 41, '41': 'RSQRT',
+    SELECT: 42, '42': 'SELECT',
+    EQUAL: 43, '43': 'EQUAL',
+    GREATER: 44, '44': 'GREATER',
+    GREATER_EQUAL: 45, '45': 'GREATER_EQUAL',
+    REDUCE_ANY: 46, '46': 'REDUCE_ANY',
+    REDUCE_ALL: 47, '47': 'REDUCE_ALL',
+    REDUCE_MAX: 48, '48': 'REDUCE_MAX',
+    REDUCE_MIN: 49, '49': 'REDUCE_MIN',
+    REDUCE_PRODUCT: 50, '50': 'REDUCE_PRODUCT',
+    REDUCE_SUM: 51, '51': 'REDUCE_SUM',
+    CONCAT: 52, '52': 'CONCAT',
+    PAD: 53, '53': 'PAD',
+    RESHAPE: 54, '54': 'RESHAPE',
+    REVERSE: 55, '55': 'REVERSE',
+    SLICE: 56, '56': 'SLICE',
+    TILE: 57, '57': 'TILE',
+    TRANSPOSE: 58, '58': 'TRANSPOSE',
+    GATHER: 59, '59': 'GATHER',
+    SCATTER: 60, '60': 'SCATTER',
+    RESIZE: 61, '61': 'RESIZE',
+    CAST: 62, '62': 'CAST',
+    RESCALE: 63, '63': 'RESCALE',
+    CONST: 64, '64': 'CONST',
+    IDENTITY: 65, '65': 'IDENTITY',
+    CUSTOM: 66, '66': 'CUSTOM',
+    COND_IF: 67, '67': 'COND_IF',
+    WHILE_LOOP: 68, '68': 'WHILE_LOOP',
+    FFT2D: 69, '69': 'FFT2D',
+    RFFT2D: 70, '70': 'RFFT2D',
+    ERF: 71, '71': 'ERF',
+    DIM: 72, '72': 'DIM'
 };
 
 tosa.v0.Attribute = class {
@@ -728,117 +728,117 @@ tosa.v0.TosaGraph = class TosaGraph {
 tosa.v1 = {};
 
 tosa.v1.DType = {
-    UNKNOWN: 0,
-    BOOL: 1,
-    INT4: 2,
-    INT8: 3,
-    INT16: 4,
-    INT32: 5,
-    INT48: 6,
-    FP32: 7,
-    FP16: 8,
-    BF16: 9,
-    SHAPE: 10,
-    FP8E4M3: 11,
-    FP8E5M2: 12
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    BOOL: 1, '1': 'BOOL',
+    INT4: 2, '2': 'INT4',
+    INT8: 3, '3': 'INT8',
+    INT16: 4, '4': 'INT16',
+    INT32: 5, '5': 'INT32',
+    INT48: 6, '6': 'INT48',
+    FP32: 7, '7': 'FP32',
+    FP16: 8, '8': 'FP16',
+    BF16: 9, '9': 'BF16',
+    SHAPE: 10, '10': 'SHAPE',
+    FP8E4M3: 11, '11': 'FP8E4M3',
+    FP8E5M2: 12, '12': 'FP8E5M2'
 };
 
 tosa.v1.ResizeMode = {
-    UNKNOWN: 0,
-    NEAREST: 1,
-    BILINEAR: 2
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    NEAREST: 1, '1': 'NEAREST',
+    BILINEAR: 2, '2': 'BILINEAR'
 };
 
 tosa.v1.NanPropagationMode = {
-    UNKNOWN: 0,
-    PROPAGATE: 1,
-    IGNORE: 2
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    PROPAGATE: 1, '1': 'PROPAGATE',
+    IGNORE: 2, '2': 'IGNORE'
 };
 
 tosa.v1.RoundingMode = {
-    UNKNOWN: 0,
-    SINGLE_ROUND: 1,
-    INEXACT_ROUND: 2,
-    DOUBLE_ROUND: 3
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    SINGLE_ROUND: 1, '1': 'SINGLE_ROUND',
+    INEXACT_ROUND: 2, '2': 'INEXACT_ROUND',
+    DOUBLE_ROUND: 3, '3': 'DOUBLE_ROUND'
 };
 
 tosa.v1.Op = {
-    UNKNOWN: 0,
-    ARGMAX: 1,
-    AVG_POOL2D: 2,
-    CONV2D: 3,
-    CONV3D: 4,
-    DEPTHWISE_CONV2D: 5,
-    FFT2D: 6,
-    MATMUL: 7,
-    MAX_POOL2D: 8,
-    RFFT2D: 9,
-    TRANSPOSE_CONV2D: 10,
-    CLAMP: 11,
-    ERF: 12,
-    SIGMOID: 13,
-    TANH: 14,
-    ADD: 15,
-    ARITHMETIC_RIGHT_SHIFT: 16,
-    BITWISE_AND: 17,
-    BITWISE_OR: 18,
-    BITWISE_XOR: 19,
-    INTDIV: 20,
-    LOGICAL_AND: 21,
-    LOGICAL_LEFT_SHIFT: 22,
-    LOGICAL_RIGHT_SHIFT: 23,
-    LOGICAL_OR: 24,
-    LOGICAL_XOR: 25,
-    MAXIMUM: 26,
-    MINIMUM: 27,
-    MUL: 28,
-    POW: 29,
-    SUB: 30,
-    TABLE: 31,
-    ABS: 32,
-    BITWISE_NOT: 33,
-    CEIL: 34,
-    CLZ: 35,
-    COS: 36,
-    EXP: 37,
-    FLOOR: 38,
-    LOG: 39,
-    LOGICAL_NOT: 40,
-    NEGATE: 41,
-    RECIPROCAL: 42,
-    RSQRT: 43,
-    SIN: 44,
-    SELECT: 45,
-    EQUAL: 46,
-    GREATER: 47,
-    GREATER_EQUAL: 48,
-    REDUCE_ALL: 49,
-    REDUCE_ANY: 50,
-    REDUCE_MAX: 51,
-    REDUCE_MIN: 52,
-    REDUCE_PRODUCT: 53,
-    REDUCE_SUM: 54,
-    CONCAT: 55,
-    PAD: 56,
-    RESHAPE: 57,
-    REVERSE: 58,
-    SLICE: 59,
-    TILE: 60,
-    TRANSPOSE: 61,
-    GATHER: 62,
-    SCATTER: 63,
-    RESIZE: 64,
-    CAST: 65,
-    RESCALE: 66,
-    CONST: 67,
-    IDENTITY: 68,
-    CUSTOM: 69,
-    COND_IF: 70,
-    WHILE_LOOP: 71,
-    VARIABLE: 72,
-    VARIABLE_WRITE: 73,
-    VARIABLE_READ: 74,
-    CONST_SHAPE: 75
+    UNKNOWN: 0, '0': 'UNKNOWN',
+    ARGMAX: 1, '1': 'ARGMAX',
+    AVG_POOL2D: 2, '2': 'AVG_POOL2D',
+    CONV2D: 3, '3': 'CONV2D',
+    CONV3D: 4, '4': 'CONV3D',
+    DEPTHWISE_CONV2D: 5, '5': 'DEPTHWISE_CONV2D',
+    FFT2D: 6, '6': 'FFT2D',
+    MATMUL: 7, '7': 'MATMUL',
+    MAX_POOL2D: 8, '8': 'MAX_POOL2D',
+    RFFT2D: 9, '9': 'RFFT2D',
+    TRANSPOSE_CONV2D: 10, '10': 'TRANSPOSE_CONV2D',
+    CLAMP: 11, '11': 'CLAMP',
+    ERF: 12, '12': 'ERF',
+    SIGMOID: 13, '13': 'SIGMOID',
+    TANH: 14, '14': 'TANH',
+    ADD: 15, '15': 'ADD',
+    ARITHMETIC_RIGHT_SHIFT: 16, '16': 'ARITHMETIC_RIGHT_SHIFT',
+    BITWISE_AND: 17, '17': 'BITWISE_AND',
+    BITWISE_OR: 18, '18': 'BITWISE_OR',
+    BITWISE_XOR: 19, '19': 'BITWISE_XOR',
+    INTDIV: 20, '20': 'INTDIV',
+    LOGICAL_AND: 21, '21': 'LOGICAL_AND',
+    LOGICAL_LEFT_SHIFT: 22, '22': 'LOGICAL_LEFT_SHIFT',
+    LOGICAL_RIGHT_SHIFT: 23, '23': 'LOGICAL_RIGHT_SHIFT',
+    LOGICAL_OR: 24, '24': 'LOGICAL_OR',
+    LOGICAL_XOR: 25, '25': 'LOGICAL_XOR',
+    MAXIMUM: 26, '26': 'MAXIMUM',
+    MINIMUM: 27, '27': 'MINIMUM',
+    MUL: 28, '28': 'MUL',
+    POW: 29, '29': 'POW',
+    SUB: 30, '30': 'SUB',
+    TABLE: 31, '31': 'TABLE',
+    ABS: 32, '32': 'ABS',
+    BITWISE_NOT: 33, '33': 'BITWISE_NOT',
+    CEIL: 34, '34': 'CEIL',
+    CLZ: 35, '35': 'CLZ',
+    COS: 36, '36': 'COS',
+    EXP: 37, '37': 'EXP',
+    FLOOR: 38, '38': 'FLOOR',
+    LOG: 39, '39': 'LOG',
+    LOGICAL_NOT: 40, '40': 'LOGICAL_NOT',
+    NEGATE: 41, '41': 'NEGATE',
+    RECIPROCAL: 42, '42': 'RECIPROCAL',
+    RSQRT: 43, '43': 'RSQRT',
+    SIN: 44, '44': 'SIN',
+    SELECT: 45, '45': 'SELECT',
+    EQUAL: 46, '46': 'EQUAL',
+    GREATER: 47, '47': 'GREATER',
+    GREATER_EQUAL: 48, '48': 'GREATER_EQUAL',
+    REDUCE_ALL: 49, '49': 'REDUCE_ALL',
+    REDUCE_ANY: 50, '50': 'REDUCE_ANY',
+    REDUCE_MAX: 51, '51': 'REDUCE_MAX',
+    REDUCE_MIN: 52, '52': 'REDUCE_MIN',
+    REDUCE_PRODUCT: 53, '53': 'REDUCE_PRODUCT',
+    REDUCE_SUM: 54, '54': 'REDUCE_SUM',
+    CONCAT: 55, '55': 'CONCAT',
+    PAD: 56, '56': 'PAD',
+    RESHAPE: 57, '57': 'RESHAPE',
+    REVERSE: 58, '58': 'REVERSE',
+    SLICE: 59, '59': 'SLICE',
+    TILE: 60, '60': 'TILE',
+    TRANSPOSE: 61, '61': 'TRANSPOSE',
+    GATHER: 62, '62': 'GATHER',
+    SCATTER: 63, '63': 'SCATTER',
+    RESIZE: 64, '64': 'RESIZE',
+    CAST: 65, '65': 'CAST',
+    RESCALE: 66, '66': 'RESCALE',
+    CONST: 67, '67': 'CONST',
+    IDENTITY: 68, '68': 'IDENTITY',
+    CUSTOM: 69, '69': 'CUSTOM',
+    COND_IF: 70, '70': 'COND_IF',
+    WHILE_LOOP: 71, '71': 'WHILE_LOOP',
+    VARIABLE: 72, '72': 'VARIABLE',
+    VARIABLE_WRITE: 73, '73': 'VARIABLE_WRITE',
+    VARIABLE_READ: 74, '74': 'VARIABLE_READ',
+    CONST_SHAPE: 75, '75': 'CONST_SHAPE'
 };
 
 tosa.v1.Attribute = class {
